Index: llvm-toolchain-snapshot_14~++20220116120030+696f9706f34d/clang/tools/scan-build-py/libexec/analyze-c++
===================================================================
--- llvm-toolchain-snapshot_14~++20220116120030+696f9706f34d.orig/clang/tools/scan-build-py/libexec/analyze-c++
+++ llvm-toolchain-snapshot_14~++20220116120030+696f9706f34d/clang/tools/scan-build-py/libexec/analyze-c++
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 # Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 # See https://llvm.org/LICENSE.txt for license information.
Index: llvm-toolchain-snapshot_14~++20220116120030+696f9706f34d/clang/tools/scan-build-py/libexec/analyze-cc
===================================================================
--- llvm-toolchain-snapshot_14~++20220116120030+696f9706f34d.orig/clang/tools/scan-build-py/libexec/analyze-cc
+++ llvm-toolchain-snapshot_14~++20220116120030+696f9706f34d/clang/tools/scan-build-py/libexec/analyze-cc
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 # Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 # See https://llvm.org/LICENSE.txt for license information.
Index: llvm-toolchain-snapshot_14~++20220116120030+696f9706f34d/clang/tools/scan-build-py/libexec/intercept-c++
===================================================================
--- llvm-toolchain-snapshot_14~++20220116120030+696f9706f34d.orig/clang/tools/scan-build-py/libexec/intercept-c++
+++ llvm-toolchain-snapshot_14~++20220116120030+696f9706f34d/clang/tools/scan-build-py/libexec/intercept-c++
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 # Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 # See https://llvm.org/LICENSE.txt for license information.
Index: llvm-toolchain-snapshot_14~++20220116120030+696f9706f34d/clang/tools/scan-build-py/libexec/intercept-cc
===================================================================
--- llvm-toolchain-snapshot_14~++20220116120030+696f9706f34d.orig/clang/tools/scan-build-py/libexec/intercept-cc
+++ llvm-toolchain-snapshot_14~++20220116120030+696f9706f34d/clang/tools/scan-build-py/libexec/intercept-cc
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 # Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
 # See https://llvm.org/LICENSE.txt for license information.
